@@ -20,6 +20,7 @@ from horizon import tabs
 from muranodashboard.environments.consts import LOG_LEVEL_TO_COLOR
 from muranodashboard.environments.consts import LOG_LEVEL_TO_TEXT
 from openstack_dashboard.api import nova as nova_api
+from openstack_dashboard.api import heat as heat_api
 
 from muranodashboard.environments import api
 from muranodashboard.environments.tables import STATUS_DISPLAY_CHOICES
@@ -72,6 +73,9 @@ class OverviewTab(tabs.Tab):
         if hasattr(service_data, 'uri'):
             detail_info['Load Balancer URI'] = service_data.uri
 
+        if hasattr(service_data, 'floatingip'):
+            detail_info['Floating IP'] = service_data.floatingip
+
         #check for deployed services so additional information can be added
         units = []
         for unit in service_data.units:
@@ -87,21 +91,33 @@ class OverviewTab(tabs.Tab):
             instances = nova_api.server_list(request)[0]
 
             # HEAT always adds e before instance name
-            instance_name = 'e' + environment_id + '.' + instance_hostname
+            instance_name = 'e' + environment_id + '-' + instance_hostname
 
             for instance in instances:
-                if instance.name == instance_name:
+                if instance_name in instance.name:
                     unit_detail['instance'] = {
                         'id': instance.id,
-                        'name': instance_name
+                        'name': instance.name
                     }
                     break
 
+            # add stack info
+            stack_name = 'e' + environment_id
+            existing_stacks = heat_api.stacks_list(request)
+            for stack in existing_stacks:
+                if stack.stack_name == stack_name:
+                    unit_detail['stack'] = {
+                        'id': stack.id,
+                        'name': stack.stack_name
+                    }
+                    break
+
+            unit_detail['Floating IP'] = unit.get('floatingip')
+
             if len(service_data.units) > 1:
                 units.append(unit_detail)
             else:
                 detail_info.update(unit_detail)
-
         return {'service': detail_info, 'units': units}
 
 
